(use-modules 
  (gnu)
  (gnu packages)
  (gnu packages shells)
  (gnu packages bash)
	(gnu packages package-management)
  (nongnu packages linux)
  (nongnu system linux-initrd))
(use-service-modules cups desktop networking ssh xorg)

(operating-system
  ;; Use nonguix (nonfree) linux
  (kernel linux)
  (initrd microcode-initrd)
  (firmware (list linux-firmware))

  ;; Configure basic properties
  (locale "en_US.utf8")
  (timezone "America/Chicago")
  (keyboard-layout (keyboard-layout "us"))
  (host-name "timberhearth")

  ;; The list of user accounts ('root' is implicit).
  (users (cons* (user-account
                  (name "nora")
                  (comment "Leonora Tindall")
                  (group "users")
                  (home-directory "/home/nora")
		  (shell (file-append zsh "/bin/zsh"))
                  (supplementary-groups '("wheel" "netdev" "audio" "video")))
                %base-user-accounts))

  ;; Packages installed system-wide.  Users can also install packages
  ;; under their own account: use 'guix search KEYWORD' to search
  ;; for packages and 'guix install PACKAGE' to install a package.
  (packages (append (list
  	bash
		zsh
		flatpak
		nix
	) %base-packages))

  ;; Below is the list of system services.  To search for available
  ;; services, run 'guix system search KEYWORD' in a terminal.
  (services
   (append
     (list 
       (service plasma-desktop-service-type)
       ;; To configure OpenSSH, pass an 'openssh-configuration'
       ;; record as a second argument to 'service' below.
       (service openssh-service-type)
       (service cups-service-type)
       (set-xorg-configuration
         (xorg-configuration (keyboard-layout keyboard-layout))))
      (modify-services %desktop-services
      (guix-service-type config => (guix-configuration
       (inherit config)
       (substitute-urls
	(append (list "https://substitutes.nonguix.org") %default-substitute-urls))
       (authorized-keys
	(append (list (local-file "./data/nonguix-substitute-signing-key.pub")) %default-authorized-guix-keys)
      ))))))

  (bootloader (bootloader-configuration
                (bootloader grub-efi-bootloader)
                (targets (list "/boot/efi"))
                (keyboard-layout keyboard-layout)))
  (mapped-devices (list (mapped-device
                          (source (uuid "24df928d-afbc-4ff6-b1e6-3214cd35964f"))
                          (target "home")
                          (type luks-device-mapping))
                        (mapped-device
                          (source (uuid "9c576944-482b-4133-b431-e8e2548febc8"))
                          (target "root")
                          (type luks-device-mapping))))

  ;; The list of file systems that get "mounted".  The unique
  ;; file system identifiers there ("UUIDs") can be obtained
  ;; by running 'blkid' in a terminal.
  (file-systems (cons* (file-system
                         (mount-point "/home")
                         (device "/dev/mapper/home")
                         (type "ext4")
                         (dependencies mapped-devices))
                       (file-system
                         (mount-point "/")
                         (device "/dev/mapper/root")
                         (type "ext4")
                         (dependencies mapped-devices))
                       (file-system
                         (mount-point "/boot/efi")
                         (device (uuid "4B0D-68F7"
                                       'fat32))
                         (type "vfat")) %base-file-systems)))
